<?php

declare(strict_types=1);

namespace Drupal\ckeditor_readmore\Plugin\Filter;

use Drupal\filter\FilterProcessResult;
use Drupal\filter\Plugin\FilterBase;

/**
 * Provides a filter to attach the custom library to readmore.
 *
 * @Filter(
 *   id = "filter_readmore",
 *   title = @Translation("Filter readmore"),
 *   description = @Translation("Attach ckeditor_readmore related library to elements."),
 *   type = Drupal\filter\Plugin\FilterInterface::TYPE_TRANSFORM_REVERSIBLE
 * )
 */
final class ReadMoreFilter extends FilterBase {

  /**
   * {@inheritdoc}
   */
  public function process($text, $langcode) {
    $result = new FilterProcessResult($text);
    if (stristr($text, 'data-readmore-type') !== FALSE && !array_search('ckeditor_readmore/ckeditor_readmore', $result->getAttachments()['library'] ?? [])) {
      // Add the ckeditor_readmore if data-readmore-type data attribute is
      // present.
      $result->addAttachments([
        'library' => [
          'ckeditor_readmore/ckeditor_readmore',
        ],
      ]);
    }
    return $result;
  }
}
